@@ -1,2 +1,2 @@
 from .ffc_client import FfcClient
-from .models import FfcUser
\ No newline at end of file
+from .ffc_user import FfcUser
\ No newline at end of file
